@@ -1,5 +1,5 @@
 
 from pycerberus.lib.attribute_dict import *
 from pycerberus.lib.simple_super import *
-from pycerberus.lib.testcase import *
+from pycerberus.lib.pythonic_testcase import *
 
