@@ -2,7 +2,7 @@
 "Release information about pycerberus."
 
 name = 'pycerberus'
-version = '0.4.2'
+version = '0.5'
 description = 'Highly flexible, no magic input validation library'
 long_description = '''
 pycerberus is a framework to check user data thoroughly so that you can protect
@@ -30,6 +30,39 @@ your application from malicious (or just garbled) input data.
 Changelog
 ******************************
 
+0.5 (05.08.2013)
+====================
+- 'allow_additional_parameters' can now be specified in the schema constructor
+  directly as well as a parameter for a declarative schema
+- new ForEach validator to validate a list of items with the same validator
+- added 'min_length', 'max_length' parameters when instantiating a 
+  StringValidator
+- InvalidDataErrors can return a list of errors using '.errors()'
+- All validator messages can be overridden during instantiation by specifying
+  ``messages`` attribute,
+- new OneOf validator to validate that a value is in a given list of allowed
+  values
+- added constructor parameter 'filter_unvalidated_parameters' (default True) 
+  for SchemaValidators to pass unvalidated parameters instead of removing them
+- InvalidDataErrors can "unpack" their errors so that an ordinary dict is used
+  as container for sub-errors (instead of another InvalidDataError with an 
+  error_dict)
+- new BooleanCheckbox validator to validate typical HTML checkboxes
+- new API method for all validators: '.copy()' returns a clone of the validator
+- new MatchingFields form validator (typically used to verify a password 
+  confirmation field)
+- new AgreeToConditionsCheckbox validator which works like a BooleanCheckbox 
+  but enforces a trueish value
+- EmailAddressValidator accepts also '-' and '+' characters in local part
+
+API changes:
+------------
+ - BaseValidator.error() is deprecated now as the name does not really reflect
+   that the method also raised the exception. I added a new method named 
+   '.raise_error()' which behaves exactly like the old .error() method. In 
+   addition there is a new method '.exception()' which only creates an exception
+   instance.
+
 0.4.2 (05.05.2011)
 ====================
 - More fixes for source distribution because of missing files in tar.gz
