@@ -2,7 +2,8 @@
 #
 # The MIT License
 # 
-# Copyright (c) 2010 Felix Schwarz <felix.schwarz@oss.schwarz.eu>
+# Copyright (c) 2010-2011 Felix Schwarz <felix.schwarz@oss.schwarz.eu>
+# Modified 2011 Andrew Fleenor at Fastsoft <andrew@fastsoft.com>
 # 
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -24,17 +25,19 @@
 
 from pycerberus.api import Validator
 from pycerberus.compat import set
-from pycerberus.errors import InvalidDataError
-from pycerberus.lib import AttrDict, PythonicTestCase
+from pycerberus.errors import InvalidArgumentsError, InvalidDataError
+from pycerberus.lib import AttrDict
+from pycerberus.lib.pythonic_testcase import *
+from pycerberus.test_util import ValidationTest
 from pycerberus.schema import SchemaValidator
 from pycerberus.validators import IntegerValidator, StringValidator
 
 
 
-class SchemaTest(PythonicTestCase):
+class SchemaTest(ValidationTest):
     
-    def _schema(self, fields=('id',), formvalidators=()):
-        schema = SchemaValidator()
+    def _schema(self, fields=('id',), formvalidators=(), **kwargs):
+        schema = SchemaValidator(**kwargs)
         assert set(fields).issubset(set(('id', 'key')))
         if 'id' in fields:
             schema.add('id', IntegerValidator())
@@ -63,15 +66,19 @@ class SchemaTest(PythonicTestCase):
     
     def test_can_retrieve_validator_for_field(self):
         schema = self._schema(('id', 'key'))
-        self.assert_isinstance(schema.validator_for('id'), IntegerValidator)
-        self.assert_isinstance(schema.validator_for('key'), StringValidator)
+        assert_isinstance(schema.validator_for('id'), IntegerValidator)
+        assert_isinstance(schema.validator_for('key'), StringValidator)
+
+    def test_can_specify_allow_additional_params_at_construction(self):
+        schema = SchemaValidator(allow_additional_parameters=False)
+        self.assert_equals(False, schema.allow_additional_parameters)
     
     # -------------------------------------------------------------------------
     # processing / validation
     
     def test_non_dict_inputs_raise_invaliddataerror(self):
-        self.assert_raises(InvalidDataError, SchemaValidator().process, 'foo')
-        exception = self.assert_raises(InvalidDataError, SchemaValidator().process, [])
+        assert_raises(InvalidDataError, lambda: SchemaValidator().process('foo'))
+        exception = assert_raises(InvalidDataError, lambda: SchemaValidator().process([]))
         self.assert_equals('invalid_type', exception.details().key())
     
     def test_can_process_single_value(self):
@@ -86,7 +93,7 @@ class SchemaTest(PythonicTestCase):
     
     def test_can_retrieve_information_about_error(self):
         schema = self._schema()
-        error = self.assert_raises(InvalidDataError, schema.process, {'id': 'invalid'}).details()
+        error = assert_raises(InvalidDataError, lambda: schema.process({'id': 'invalid'})).details()
         self.assert_equals('invalid', error.value())
         self.assert_equals('invalid_number', error.key())
         self.assert_equals('Please enter a number.', error.msg())
@@ -98,7 +105,7 @@ class SchemaTest(PythonicTestCase):
     
     def test_missing_fields_are_validated_as_well(self):
         schema = self._schema()
-        self.assert_raises(InvalidDataError, schema.process, {})
+        assert_raises(InvalidDataError, lambda: schema.process({}))
     
     def test_converted_dict_contains_only_validated_fields(self):
         schema = self._schema()
@@ -106,14 +113,14 @@ class SchemaTest(PythonicTestCase):
     
     def test_can_get_all_errors_at_once(self):
         schema = self._schema(('id', 'key'))
-        exception = self.assert_raises(InvalidDataError, schema.process, 
-                                       {'id': 'invalid', 'key': None})
+        exception = assert_raises(InvalidDataError, 
+            lambda: schema.process({'id': 'invalid', 'key': None}))
         self.assert_length(2, exception.error_dict())
     
     def test_exception_contains_information_about_all_errrors(self):
         schema = self._schema(('id', 'key'))
-        exception = self.assert_raises(InvalidDataError, schema.process, 
-                                       {'id': 'invalid', 'key': {}})
+        exception = assert_raises(InvalidDataError, 
+            lambda: schema.process({'id': 'invalid', 'key': {}}))
         self.assert_equals(['id', 'key'], exception.error_dict().keys())
         id_error = exception.error_for('id').details()
         self.assert_equals('invalid', id_error.value())
@@ -123,13 +130,41 @@ class SchemaTest(PythonicTestCase):
         self.assert_equals({}, key_error.value())
         self.assert_equals('invalid_type', key_error.key())
     
+    # -------------------------------------------------------------------------
+    # warn about additional parameters
+    
     def test_schema_can_bail_out_if_additional_items_are_detected(self):
         schema = self._schema(fields=())
         self.assert_equals({}, schema.process(dict(foo=42)))
         schema.set_internal_state_freeze(False)
         schema.set_allow_additional_parameters(False)
-        self.assert_raises(InvalidDataError, schema.process, dict(foo=42))
+        assert_raises(InvalidDataError, lambda: schema.process(dict(foo=42)))
         
+    def test_exception_contains_information_about_invalid_and_extra_fields(self):
+        schema = self._schema(allow_additional_parameters=False)
+
+        exception = assert_raises(InvalidDataError, 
+            lambda: schema.process({'id': 'invalid', 'foo':'heh'}))
+        self.assert_equals(2, len(exception.error_dict().items()))
+    
+    # -------------------------------------------------------------------------
+    # pass unvalidated parameters
+    
+    def test_filters_unvalidated_parameters_by_default(self):
+        schema = self._schema(filter_unvalidated_parameters=True)
+        self.init_validator(schema)
+        
+        assert_equals({'id': 42}, self.process({'id': '42', 'foo': 'bar'}))
+    
+    def test_passes_unvalidated_parameters_if_specified(self):
+        schema = self._schema(filter_unvalidated_parameters=False)
+        self.init_validator(schema)
+
+        assert_equals({'id': 42, 'foo': 'bar'}, self.process({'id': '42', 'foo': 'bar'}))
+    
+    def test_prevents_schema_instantiation_with_exception_for_additional_items_and_passing_unvalidated(self):
+        assert_raises(InvalidArgumentsError,
+            lambda: self._schema(allow_additional_parameters=False, filter_unvalidated_parameters=False))
     
     # -------------------------------------------------------------------------
     # form validators
@@ -151,7 +186,7 @@ class SchemaTest(PythonicTestCase):
     
     def test_formvalidators_are_executed(self):
         schema = self._schema(formvalidators=(self._failing_validator(), ))
-        self.assert_raises(Exception, schema.process, {'id': '42'})
+        assert_raises(Exception, lambda: schema.process({'id': '42'}))
     
     def test_formvalidators_can_modify_fields(self):
         class FormValidator(Validator):
@@ -162,7 +197,7 @@ class SchemaTest(PythonicTestCase):
     
     def test_formvalidators_are_not_executed_if_field_validator_failed(self):
         schema = self._schema(formvalidators=(self._failing_validator(), ))
-        error = self.assert_raises(InvalidDataError, schema.process, {'id': 'invalid'})
+        error = assert_raises(InvalidDataError, lambda: schema.process({'id': 'invalid'}))
         self.assert_equals(['id'], error.error_dict().keys())
     
     def test_formvalidators_are_executed_after_field_validators(self):
@@ -198,7 +233,26 @@ class SchemaTest(PythonicTestCase):
         schema.add_formvalidator(first_validator)
         schema.add_formvalidator(self._failing_validator())
         
-        error = self.assert_raises(InvalidDataError, schema.process, {'id': '42'})
+        error = assert_raises(InvalidDataError, lambda: schema.process({'id': '42'}))
         self.assert_equals('expected', error.details().key())
-
+    
+    # -------------------------------------------------------------------------
+    # sub-schemas
+    
+    def _user_schema(self):
+        user_schema = self._schema(fields=())
+        user_schema.add('first_name', StringValidator)
+        user_schema.add('last_name', StringValidator)
+        return user_schema
+    
+    def _schema_with_user_subschema(self):
+        schema = self._schema(fields=())    
+        schema.add('user', self._user_schema())
+        return schema
+    
+    def test_can_declare_schema_with_subschema(self):
+        self.init_validator(self._schema_with_user_subschema())
+        
+        user_input = {'user': {'first_name': 'Foo', 'last_name': 'Bar'}}
+        assert_equals(user_input, self.process(user_input))
 
