@@ -2,7 +2,7 @@
 #
 # The MIT License
 # 
-# Copyright (c) 2009-2010 Felix Schwarz <felix.schwarz@oss.schwarz.eu>
+# Copyright (c) 2009-2010, 2012 Felix Schwarz <felix.schwarz@oss.schwarz.eu>
 # 
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -24,13 +24,34 @@
 
 from pycerberus import EmptyError, InvalidArgumentsError, Validator
 from pycerberus.api import NoValueSet
+from pycerberus.lib.pythonic_testcase import *
 from pycerberus.test_util import ValidationTest
 
 
-class ValidatorParametersTest(ValidationTest):
+class ValidatorTest(ValidationTest):
     
     def test_bail_out_if_unknown_parameters_are_passed_to_constructor(self):
-        self.assert_raises(Exception, lambda: Validator(invalid='fnord'))
+        assert_raises(Exception, lambda: Validator(invalid='fnord'))
+    
+    def test_revert_conversion(self):
+        self.init_validator(Validator())
+        assert_equals(u'ö', self.revert_conversion(u'ö'))
+        assert_equals('1', self.revert_conversion(1))
+        assert_equals(None, self.revert_conversion(None))
+    
+    def test_can_copy_itself(self):
+        # This is the same test as in BaseValidator - however Validator has
+        # thread-safety built-in so we need extra code
+        class MutableValidator(Validator):
+            acceptable_values = [1, 2, 3]
+        validator = MutableValidator()
+        
+        a = validator.copy()
+        b = validator.copy()
+        a.acceptable_values.append(4)
+        
+        assert_contains(4, a.acceptable_values)
+        assert_not_contains(4, b.acceptable_values)
 
 
 class DefaultAndRequiredValuesTest(ValidationTest):
@@ -83,11 +104,11 @@ class DefaultAndRequiredValuesTest(ValidationTest):
     def test_raise_exception_if_required_value_is_missing(self):
         self.assert_equals(42,  Validator(required=True).process(42))
         self.assert_none(Validator(required=False).process(None))
-        self.assert_raises(EmptyError, Validator(required=True).process, None)
-        self.assert_raises(EmptyError, Validator().process, None)
+        assert_raises(EmptyError, lambda: Validator(required=True).process(None))
+        assert_raises(EmptyError, lambda: Validator().process(None))
     
     def test_raise_exception_if_value_is_required_but_default_is_set_to_prevent_errors(self):
-        self.assert_raises(InvalidArgumentsError, Validator, required=True, default=12)
+        assert_raises(InvalidArgumentsError, lambda: Validator(required=True, default=12))
 
 
 class StripValueTest(ValidationTest):
